==> pyhdtoolkit-1.3.2.tar.gz: pyhdtoolkit-1.3.2/README.md <==
<h1 align="center">
  <b>PyhDToolkit</b>
</h1>

<p align="center">
  <!-- PyPi Version -->
  <a href="https://pypi.org/project/pyhdtoolkit">
    <img alt="PyPI Version" src="https://img.shields.io/pypi/v/pyhdtoolkit?label=PyPI&logo=PyPI">
  </a>

  <!-- Github Release -->
  <a href="https://github.com/fsoubelet/PyhDToolkit/releases">
    <img alt="Github Release" src="https://img.shields.io/github/v/release/fsoubelet/PyhDToolkit?color=orange&label=Release&logo=Github">
  </a>

  <br/>

  <!-- Github Actions Build -->
  <a href="https://github.com/fsoubelet/PyhDToolkit/actions?query=workflow%3A%22Cron+Testing%22">
    <img alt="Github Actions" src="https://github.com/fsoubelet/PyhDToolkit/workflows/Tests/badge.svg">
  </a>

  <!-- Code Coverage -->
  <a href="https://codecov.io/gh/fsoubelet/PyhDToolkit">
    <img src="https://codecov.io/gh/fsoubelet/PyhDToolkit/branch/master/graph/badge.svg?token=6SO90F2MJI"/>
  </a>

  <!-- Docker Image -->
  <a href="https://hub.docker.com/r/fsoubelet/simenv">
    <img alt="Docker Image" src="https://img.shields.io/docker/image-size/fsoubelet/simenv?label=Docker&sort=date">
  </a>

  <br/>

  <!-- Code style -->
  <a href="https://github.com/psf/Black">
    <img alt="Code Style" src="https://img.shields.io/badge/Code%20Style-Black-9cf.svg">
  </a>

  <!-- Linter -->
  <a href="https://github.com/PyCQA/pylint">
    <img alt="Linter" src="https://img.shields.io/badge/Linter-Pylint-ce963f.svg">
  </a>

  <!-- Build tool -->
  <a href="https://github.com/pypa/hatch">
    <img alt="Build tool" src="https://img.shields.io/badge/Build%20Tool-Hatch-4e5dc8.svg">
  </a>

  <!-- Test runner -->
  <a href="https://github.com/pytest-dev/pytest">
    <img alt="Test runner" src="https://img.shields.io/badge/Test%20Runner-Pytest-ce963f.svg">
  </a>

  <!-- License -->
  <a href="https://github.com/fsoubelet/PyhDToolkit/blob/master/LICENSE">
    <img alt="License" src="https://img.shields.io/github/license/fsoubelet/PyhDToolkit?color=9cf&label=License">
  </a>
</p>

<p align="center">
  ♻️ An all-in-one package for Python work in my PhD ♻️
</p>

<p align="center">
  <!-- General DOI -->
  <a href="https://zenodo.org/badge/latestdoi/227081702">
    <img alt="DOI" src="https://zenodo.org/badge/227081702.svg">
  </a>
</p>

<p align="center">
  <a href="https://www.python.org/">
    <img alt="Made With Python" src="https://forthebadge.com/images/badges/made-with-python.svg">
  </a>
</p>

Link to [documentation].

## License

Copyright &copy; 2019 Felix Soubelet. [MIT License](LICENSE)

[documentation]: https://fsoubelet.github.io/PyhDToolkit/

==> pyhdtoolkit-1.7.0.tar.gz: pyhdtoolkit-1.7.0/README.md <==
<h1 align="center">
  <b>PyhDToolkit</b>
</h1>

<p align="center">
  <!-- PyPi Version -->
  <a href="https://pypi.org/project/pyhdtoolkit">
    <img alt="PyPI Version" src="https://img.shields.io/pypi/v/pyhdtoolkit?label=PyPI&logo=PyPI">
  </a>

  <!-- Github Release -->
  <a href="https://github.com/fsoubelet/PyhDToolkit/releases">
    <img alt="Github Release" src="https://img.shields.io/github/v/release/fsoubelet/PyhDToolkit?color=blue&label=Release&logo=Github">
  </a>

  <br/>

  <!-- Github Actions Build -->
  <a href="https://github.com/fsoubelet/PyhDToolkit/actions?query=workflow%3A%22Cron+Testing%22">
    <img alt="Github Actions" src="https://github.com/fsoubelet/PyhDToolkit/workflows/Tests/badge.svg">
  </a>

  <!-- Docker Image -->
  <a href="https://hub.docker.com/r/fsoubelet/simenv">
    <img alt="Docker Image" src="https://img.shields.io/docker/image-size/fsoubelet/simenv?label=Docker&sort=date">
  </a>

  <!-- Code Coverage -->
  <a href="https://codecov.io/gh/fsoubelet/PyhDToolkit">
    <img src="https://codecov.io/gh/fsoubelet/PyhDToolkit/branch/master/graph/badge.svg?token=6SO90F2MJI"/>
  </a>

  <br/>

  <!-- Code style -->
  <a href="https://github.com/psf/Black">
    <img alt="Code Style" src="https://img.shields.io/badge/Code%20Style-Black-9cf.svg">
  </a>

  <!-- Linter -->
  <a href="https://github.com/astral-sh/ruff">
    <img alt="Linter" src="https://img.shields.io/badge/Linter-Ruff-ce963f.svg">
  </a>

  <!-- Build tool -->
  <a href="https://github.com/astral-sh/uv">
    <img alt="Build tool" src="https://img.shields.io/badge/Build%20Tool-uv-4e5dc8.svg">
  </a>

  <!-- Test runner -->
  <a href="https://github.com/pytest-dev/pytest">
    <img alt="Test runner" src="https://img.shields.io/badge/Test%20Runner-Pytest-ce963f.svg">
  </a>

  <!-- License -->
  <a href="https://github.com/fsoubelet/PyhDToolkit/blob/master/LICENSE">
    <img alt="License" src="https://img.shields.io/github/license/fsoubelet/PyhDToolkit?color=9cf&label=License">
  </a>
</p>

<p align="center">
  ♻️ An all-in-one package for Python work in my PhD ♻️
</p>

<p align="center">
  <!-- General DOI -->
  <a href="https://zenodo.org/badge/latestdoi/227081702">
    <img alt="DOI" src="https://zenodo.org/badge/227081702.svg">
  </a>
</p>

<p align="center">
  <a href="https://www.python.org/">
    <img alt="Made With Python" src="https://forthebadge.com/images/badges/made-with-python.svg">
  </a>
</p>

Link to [documentation].

## License

Copyright &copy; 2019 Felix Soubelet. [MIT License](LICENSE)

[documentation]: https://fsoubelet.github.io/PyhDToolkit/
